pub fn write(path: impl AsRef<Path>, contents: impl AsRef<[u8]>) -> Result<()>Expand description
Write a slice as the entire contents of a file
This function will create a file if it does not exist, and will entirely replace its contents if it does
Depending on the platform, this function may fail if the full directory path does not exist
This is a convenience function for using File::create and
write_all with fewer imports
close_already differences
None